@@ -103,7 +103,7 @@ hasExt <- function(fleNme = "", extNme = c("")) {
 }
 
 hasPkg <- function(usePkg = c()) {
-    all(sapply(usePkg, function(X) nzchar(system.file(package = X))))
+    all(vapply(usePkg, function(X) nzchar(system.file(package = X)), logical(1)))
 }
 
 nrmFle <- function(fleNme = "") {
@@ -117,9 +117,9 @@ fmtFlI <- function(fleInp = c(), minLng = 1, maxLng = Inf, excExt = "") {
         stop(sprintf("The fleInp-argument is supposed to be a character vector with a minimal length of %.0f and a maximal length of %.0f (current length is %.0f).%s",
                      minLng, maxLng, length(fleInp), ifelse(length(fleInp) > maxLng, "\n  If you would like to process several files, call the function individually for each.", "")))
     }
-    fleInp <- unname(sapply(fleInp, nrmFle))
-    all(sapply(fleInp, chkFle))
-    all(sapply(fleInp, chkExt, setdiff(vldExt, excExt)))
+    fleInp <- unname(vapply(fleInp, nrmFle, character(1)))
+    all(vapply(fleInp, chkFle, logical(1)))
+    all(vapply(fleInp, chkExt, logical(1), setdiff(vldExt, excExt)))
     fleInp
 }
 
@@ -155,7 +155,7 @@ jmvPtB <- function() {
     synPkg <- c("RProtoBuf", "jmvcore")
     if (!hasPkg(synPkg)) {
         warning(sprintf("For using protocol buffers, the package(s) \"%s\" need(s) to be installed.\n\n",
-          paste0(synPkg[!sapply(synPkg, hasPkg)], collapse = "\", \"")))
+          paste0(synPkg[!vapply(synPkg, hasPkg, logical(1))], collapse = "\", \"")))
         return(FALSE)
     }
     # check the two possible places for the jamovi.proto file
@@ -325,7 +325,7 @@ chkFld <- function(fldObj = NULL, fldNme = "", fldVal = NULL) {
 
 # =================================================================================================
 # function handling to have either a data frame or a character (pointing to a file) as input
-inp2DF <- function(dtaInp = NULL, minDF = 1, maxDF = 1, usePkg = c("foreign", "haven"), selSet = "", ...) {
+inp2DF <- function(dtaInp = NULL, minDF = 1, maxDF = 1, rmvEmp = FALSE, usePkg = c("foreign", "haven"), selSet = "", ...) {
     usePkg <- match.arg(usePkg)
     # check and format input and output files, handle / check further input arguments:
     # if the input is a data frame, it is “embedded” in a list (in order to permit to read
@@ -344,6 +344,23 @@ inp2DF <- function(dtaInp = NULL, minDF = 1, maxDF = 1, usePkg = c("foreign", "h
         clsRmv()
         stop("dtaInp must either be a data frame or a character (pointing to a location where the input file can be found).")
     }
+    # if rmvEmp is set, check for rows that are completely empty and remove them
+    if (rmvEmp) {
+        for (i in seq_along(lstDF)) {
+            blnEmp <- apply(lstDF[[i]], 1, function(x) all(is.na(x)))
+            if (blnEmp[1] && sum(diff(blnEmp) == -1) == 1) {
+                lstDF[[i]] <- lstDF[[i]][-seq(1, which(diff(blnEmp) == -1)), ]
+                blnEmp <- apply(lstDF[[i]], 1, function(x) all(is.na(x)))
+            }
+            if (blnEmp[length(blnEmp)] && sum(diff(blnEmp) == 1) == 1) {
+                lstDF[[i]] <- lstDF[[i]][seq(which(diff(blnEmp) == 1)), ]
+                blnEmp <- apply(lstDF[[i]], 1, function(x) all(is.na(x)))
+            }
+            if (any(blnEmp)) {
+                stop("Empty rows are not permitted execpt from the begin or the end of an input data frame (in such case, they are automatically removed).")
+            }
+        }
+    }
     # most functions expect only one data frame to be returned, thus, the list
     # used for reading processing those data frames is unpacked if there is
     # only one data frame to return
@@ -369,11 +386,11 @@ rtnDta <- function(dtaFrm = NULL, fleOut = "", dtaTtl = "", wrtPtB = FALSE, psvA
                 warning("psvAnl is only possible if dtaInp is a file name (analyses are not stored in data frames, only in the jamovi files).")
             }
         }
-        return()
+        return(invisible(NULL))
     } else if (isJmv() && is.character(fleOut)) {
         if (psvAnl) warning("psvAnl is only possible if fleOut is a file name (analyses are not stored in data frames, only in the jamovi files).")
         jmvOpn(dtaFrm, dtaTtl = dtaTtl)
-        return()
+        return(invisible(NULL))
     } else {
         if (psvAnl) warning("psvAnl is only possible if fleOut is a file name (analyses are not stored in data frames, only in the jamovi files).")
         return(dtaFrm)
