@@ -12,52 +12,69 @@ test_that("long2wide_omv works", {
     df4Chk <- read_omv(nmeOut)
     expect_s3_class(df4Chk, "data.frame")
     expect_equal(dim(df4Chk), c(121, 25))
-    expect_equal(as.vector(sapply(df4Chk, typeof)), c("integer", rep("double", 24)))
+    expect_equal(vapply(df4Chk, typeof, character(1), USE.NAMES = FALSE), c("integer", rep("double", 24)))
     expect_equal(names(df4Chk), c("Year", paste0(rep(c("X_", "Y_"), each = 12), month.abb[rep(1:12, times = 2)])))
     expect_equal(unname(colMeans(df4Chk[-1])), c(51.05398, 51.52200, 50.90146, 47.98040, 46.28997, 53.70601, 49.47946, 49.24704, 49.92602, 44.93970, 49.37357, 47.55488,
                                                  48.56846, 48.96117, 47.64545, 46.51572, 50.94652, 47.33624, 47.53437, 55.55701, 51.50431, 50.19580, 52.81145, 43.68338), tolerance = 1e-4)
-    expect_equal(unname(unlist(sapply(df4Chk, attr, "jmv-desc"))), sprintf("%s (Month: %s)", rep(c("Variable X", "Variable Y"), each = 12), month.abb[rep(1:12, times = 2)]))
+    expect_equal(vapply(df4Chk[-1], attr, character(1), "jmv-desc", USE.NAMES = FALSE),
+      sprintf("%s (Month: %s)", rep(c("Variable X", "Variable Y"), each = 12), month.abb[rep(1:12, times = 2)]))
     unlink(nmeOut)
 
     expect_null(long2wide_omv(dtaInp = dtaTmp, fleOut = nmeOut, varID = "Year", varTme = "Month", varOrd = "vars"))
     df4Chk <- read_omv(nmeOut)
     expect_s3_class(df4Chk, "data.frame")
     expect_equal(dim(df4Chk), c(121, 25))
-    expect_equal(as.vector(sapply(df4Chk, typeof)), c("integer", rep("double", 24)))
+    expect_equal(vapply(df4Chk, typeof, character(1), USE.NAMES = FALSE), c("integer", rep("double", 24)))
     expect_equal(names(df4Chk), c("Year", paste0(rep(c("X_", "Y_"), times = 12), month.abb[rep(1:12, each = 2)])))
     expect_equal(unname(colMeans(df4Chk[-1])), c(51.05398, 48.56846, 51.52200, 48.96117, 50.90146, 47.64545, 47.98040, 46.51572, 46.28997, 50.94652, 53.70601, 47.33624,
                                                  49.47946, 47.53437, 49.24704, 55.55701, 49.92602, 51.50431, 44.93970, 50.19580, 49.37357, 52.81145, 47.55488, 43.68338), tolerance = 1e-4)
-    expect_equal(unname(unlist(sapply(df4Chk, attr, "jmv-desc"))), sprintf("%s (Month: %s)", rep(c("Variable X", "Variable Y"), times = 12), month.abb[rep(1:12, each = 2)]))
+    expect_equal(vapply(df4Chk[-1], attr, character(1), "jmv-desc", USE.NAMES = FALSE),
+      sprintf("%s (Month: %s)", rep(c("Variable X", "Variable Y"), times = 12), month.abb[rep(1:12, each = 2)]))
     unlink(nmeOut)
 
     expect_null(long2wide_omv(dtaInp = nmeInp, fleOut = nmeOut, varID = "Year", varTme = "Month", varTgt = c("X")))
     df4Chk <- read_omv(nmeOut)
     expect_s3_class(df4Chk, "data.frame")
     expect_equal(dim(df4Chk), c(121, 13))
-    expect_equal(as.vector(sapply(df4Chk, typeof)), c("integer", rep("double", 12)))
+    expect_equal(vapply(df4Chk, typeof, character(1), USE.NAMES = FALSE), c("integer", rep("double", 12)))
     expect_equal(names(df4Chk), c("Year", paste0("X_", month.abb[1:12])))
     expect_equal(unname(colMeans(df4Chk[-1])), c(51.05398, 51.52200, 50.90146, 47.98040, 46.28997, 53.70601, 49.47946, 49.24704, 49.92602, 44.93970, 49.37357, 47.55488), tolerance = 1e-4)
-    expect_equal(unname(unlist(sapply(df4Chk, attr, "jmv-desc"))), sprintf("Variable X (Month: %s)", month.abb[1:12]))
+    expect_equal(vapply(df4Chk[-1], attr, character(1), "jmv-desc", USE.NAMES = FALSE),
+      sprintf("Variable X (Month: %s)", month.abb[1:12]))
     unlink(nmeOut)
 
     expect_null(long2wide_omv(dtaInp = nmeInp, fleOut = nmeOut, varID = "Year", varTme = "Month", varTgt = c("Y")))
     df4Chk <- read_omv(nmeOut)
     expect_s3_class(df4Chk, "data.frame")
     expect_equal(dim(df4Chk), c(121, 13))
-    expect_equal(as.vector(sapply(df4Chk, typeof)), c("integer", rep("double", 12)))
+    expect_equal(vapply(df4Chk, typeof, character(1), USE.NAMES = FALSE), c("integer", rep("double", 12)))
     expect_equal(names(df4Chk), c("Year", paste0("Y_", month.abb[1:12])))
     expect_equal(unname(colMeans(df4Chk[-1])), c(48.56846, 48.96117, 47.64545, 46.51572, 50.94652, 47.33624, 47.53437, 55.55701, 51.50431, 50.19580, 52.81145, 43.68338), tolerance = 1e-4)
-    expect_equal(unname(unlist(sapply(df4Chk, attr, "jmv-desc"))), sprintf("Variable Y (Month: %s)", month.abb[1:12]))
+    expect_equal(vapply(df4Chk[-1], attr, character(1), "jmv-desc", USE.NAMES = FALSE),
+      sprintf("Variable Y (Month: %s)", month.abb[1:12]))
     unlink(nmeOut)
 
     df4Chk <- long2wide_omv(dtaInp = dtaTmp, varID = "Year", varTme = "Month")
     expect_s3_class(df4Chk, "data.frame")
     expect_equal(dim(df4Chk), c(121, 25))
-    expect_equal(as.vector(sapply(df4Chk, typeof)), c("integer", rep("double", 24)))
+    expect_equal(vapply(df4Chk, typeof, character(1), USE.NAMES = FALSE), c("integer", rep("double", 24)))
     expect_equal(names(df4Chk), c("Year", paste0(rep(c("X_", "Y_"), each = 12), month.abb[rep(1:12, 2)])))
     expect_equal(unname(colMeans(df4Chk[-1])), c(51.05398, 51.52200, 50.90146, 47.98040, 46.28997, 53.70601, 49.47946, 49.24704, 49.92602, 44.93970, 49.37357, 47.55488,
                                                  48.56846, 48.96117, 47.64545, 46.51572, 50.94652, 47.33624, 47.53437, 55.55701, 51.50431, 50.19580, 52.81145, 43.68338), tolerance = 1e-4)
-    expect_equal(unname(unlist(sapply(df4Chk, attr, "jmv-desc"))), sprintf("%s (Month: %s)", rep(c("Variable X", "Variable Y"), each = 12), month.abb[rep(1:12, times = 2)]))
+    expect_equal(vapply(df4Chk[-1], attr, character(1), "jmv-desc", USE.NAMES = FALSE),
+      sprintf("%s (Month: %s)", rep(c("Variable X", "Variable Y"), each = 12), month.abb[rep(1:12, times = 2)]))
+
+    expect_null(long2wide_omv(dtaInp = nmeInp, fleOut = nmeOut, varID = "Year", varTme = "Month", varSep = "."))
+    df4Chk <- read_omv(nmeOut)
+    expect_s3_class(df4Chk, "data.frame")
+    expect_equal(dim(df4Chk), c(121, 25))
+    expect_equal(vapply(df4Chk, typeof, character(1), USE.NAMES = FALSE), c("integer", rep("double", 24)))
+    expect_equal(names(df4Chk), c("Year", paste0(rep(c("X.", "Y."), each = 12), month.abb[rep(1:12, times = 2)])))
+    expect_equal(unname(colMeans(df4Chk[-1])), c(51.05398, 51.52200, 50.90146, 47.98040, 46.28997, 53.70601, 49.47946, 49.24704, 49.92602, 44.93970, 49.37357, 47.55488,
+                                                 48.56846, 48.96117, 47.64545, 46.51572, 50.94652, 47.33624, 47.53437, 55.55701, 51.50431, 50.19580, 52.81145, 43.68338), tolerance = 1e-4)
+    expect_equal(vapply(df4Chk[-1], attr, character(1), "jmv-desc", USE.NAMES = FALSE),
+      sprintf("%s (Month: %s)", rep(c("Variable X", "Variable Y"), each = 12), month.abb[rep(1:12, times = 2)]))
+    unlink(nmeOut)
 
     # more complex data set ===================================================================================================================================
     set.seed(1)
@@ -77,7 +94,8 @@ test_that("long2wide_omv works", {
     avgTmp <- aggregate(x = dtaTmp[, c("rspCrr", "rspTme")], by = dtaTmp[, c("cond", "colour", "rep")], FUN = mean)
     expect_equal(unname(colMeans(df4Chk[, sprintf("rspCrr_%s_%s_%s", avgTmp$cond, avgTmp$colour, avgTmp$rep)])), avgTmp$rspCrr)
     expect_equal(unname(colMeans(df4Chk[, sprintf("rspTme_%s_%s_%s", avgTmp$cond, avgTmp$colour, avgTmp$rep)])), avgTmp$rspTme)
-    expect_equal(unname(unlist(sapply(df4Chk, attr, "jmv-desc"))), c(unname(unlist(lblTmp[1:2])), sprintf("%s (cond: %s, colour: %s, rep: %d)",
+    expect_equal(vapply(df4Chk, attr, character(1), "jmv-desc", USE.NAMES = FALSE),
+      c(unname(unlist(lblTmp[1:2])), sprintf("%s (cond: %s, colour: %s, rep: %d)",
       rep(unname(unlist(lblTmp[6:7])), each = 24), rep(rep(c("neutral", "cong", "incong"), each = 8), times = 2), rep(c("RED", "BLUE", "GREEN", "YELLOW"), each = 2), rep(1:2, times = 24))))
 
     df4Chk <- long2wide_omv(dtaInp = dtaTmp, varID = "ID", varTme = "cond", varTgt = c("rspCrr", "rspTme"), varExc = "sex")
@@ -86,7 +104,8 @@ test_that("long2wide_omv works", {
     expect_equal(names(df4Chk), c("ID", "sex", sprintf("%s_%s", rep(c("rspCrr", "rspTme"), each = 3), rep(rep(c("cong", "incong", "neutral"), times = 2)))))
     avgTmp <- aggregate(x = dtaTmp[, c("rspCrr", "rspTme")], by = dtaTmp[, c("sex", "cond"), drop = FALSE], FUN = mean)
     expect_equal(as.vector(unlist(avgTmp[c(-1, -2)])), unname(unlist(aggregate(x = df4Chk[3:8], by = df4Chk[, "sex", drop = FALSE], FUN = mean)[-1])))
-    expect_equal(unname(unlist(sapply(df4Chk, attr, "jmv-desc"))), c(unname(unlist(lblTmp[1:2])), sprintf("%s (cond: %s)",
+    expect_equal(vapply(df4Chk, attr, character(1), "jmv-desc", USE.NAMES = FALSE),
+      c(unname(unlist(lblTmp[1:2])), sprintf("%s (cond: %s)",
       rep(unname(unlist(lblTmp[6:7])), each = 3), rep(c("cong", "incong", "neutral"), times = 2))))
 
     df4Chk <- long2wide_omv(dtaInp = dtaTmp, varID = "ID", varTme = "cond", varTgt = c("rspCrr", "rspTme"))
@@ -95,7 +114,7 @@ test_that("long2wide_omv works", {
     expect_equal(names(df4Chk), c("ID", sprintf("%s_%s", rep(c("rspCrr", "rspTme"), each = 3), rep(rep(c("cong", "incong", "neutral"), times = 2)))))
     avgTmp <- aggregate(x = dtaTmp[, c("rspCrr", "rspTme")], by = dtaTmp[, c("cond"), drop = FALSE], FUN = mean)
     expect_equal(unname(colMeans(df4Chk[2:7])), as.vector(unlist(avgTmp[-1])))
-    expect_equal(unname(unlist(sapply(df4Chk, attr, "jmv-desc"))), c(unname(unlist(lblTmp[1])), sprintf("%s (cond: %s)",
+    expect_equal(vapply(df4Chk, attr, character(1), "jmv-desc", USE.NAMES = FALSE), c(unname(unlist(lblTmp[1])), sprintf("%s (cond: %s)",
       rep(unname(unlist(lblTmp[6:7])), each = 3), rep(c("cong", "incong", "neutral"), times = 2))))
 
     df4Chk <- long2wide_omv(dtaInp = dtaTmp, varID = "ID", varTme = "cond", varTgt = c("rspCrr", "rspTme"), varExc = "sex", varOrd = "vars")
@@ -104,7 +123,7 @@ test_that("long2wide_omv works", {
     expect_equal(names(df4Chk), c("ID", "sex", sprintf("%s_%s", rep(c("rspCrr", "rspTme"), times = 3), rep(rep(c("cong", "incong", "neutral"), each = 2)))))
     avgTmp <- aggregate(x = dtaTmp[, c("rspCrr", "rspTme")], by = dtaTmp[, c("cond"), drop = FALSE], FUN = mean)
     expect_equal(unname(colMeans(df4Chk[3:8])), as.vector(t(avgTmp[-1])))
-    expect_equal(unname(unlist(sapply(df4Chk, attr, "jmv-desc"))), c(unname(unlist(lblTmp[1:2])), sprintf("%s (cond: %s)",
+    expect_equal(vapply(df4Chk, attr, character(1), "jmv-desc", USE.NAMES = FALSE), c(unname(unlist(lblTmp[1:2])), sprintf("%s (cond: %s)",
       rep(unname(unlist(lblTmp[6:7])), times = 3), rep(c("cong", "incong", "neutral"), each = 2))))
 
     df4Chk <- long2wide_omv(dtaInp = dtaTmp, varID = "ID", varTme = "cond", varTgt = c("rspCrr", "rspTme"), varExc = "sex", varAgg = "first")
@@ -113,7 +132,7 @@ test_that("long2wide_omv works", {
     expect_equal(names(df4Chk), c("ID", "sex", sprintf("%s_%s", rep(c("rspCrr", "rspTme"), each = 3), rep(rep(c("cong", "incong", "neutral"), times = 2)))))
     avgTmp <- aggregate(x = dtaTmp[, c("rspCrr", "rspTme")], by = dtaTmp[, c("ID", "cond")], FUN = "[[", 1)
     expect_equal(unname(as.matrix(df4Chk[3:8])), cbind(matrix(avgTmp[, "rspCrr"], ncol = 3), matrix(avgTmp[, "rspTme"], ncol = 3)))
-    expect_equal(unname(unlist(sapply(df4Chk, attr, "jmv-desc"))), c(unname(unlist(lblTmp[1:2])), sprintf("%s (cond: %s)",
+    expect_equal(vapply(df4Chk, attr, character(1), "jmv-desc", USE.NAMES = FALSE), c(unname(unlist(lblTmp[1:2])), sprintf("%s (cond: %s)",
       rep(unname(unlist(lblTmp[6:7])), each = 3), rep(c("cong", "incong", "neutral"), times = 2))))
 
     dtaTmp$rspCrr <- as.factor(dtaTmp$rspCrr)
